@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package App::wu;
-$App::wu::VERSION = '0.02';
+$App::wu::VERSION = '0.03';
 use WWW::Wunderground::API 0.06;
 use Cache::FileCache;
 use Carp;
@@ -84,14 +84,15 @@ App::wu - Terminal app that provides an hourly weather forecast using Weather Un
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
 This module installs the C<wu> command which prints a 36 hour weather forecast at the command line using the Wunderground API. You'll need to get a Wunderground API key (they're free) and set the environment variable C<WU_API_KEY>. Optionally you can set the environment variable C<WU_HOME_LOCATION> which sets the default location for C<wu>.
 
-    $ wu
-    Enter your location (London, UK):
+    $ wu London, UK
+    Retrieving weather forecast for London, UK ...
+
     Time      ℉   ℃   Rain %  Conditions          
      2:00 AM  56  13       5  Clear                         
      3:00 AM  55  13       6  Partly Cloudy                 
@@ -103,7 +104,7 @@ This module installs the C<wu> command which prints a 36 hour weather forecast a
 
 =head1 BUGS
 
-Windows PowerShell and cmd.exe both corrupt the Fareinheit and Celsius degrees symbols.
+Windows PowerShell and cmd.exe both corrupt the Fareinheit and Celsius degrees symbols, but other than that work fine.
 
 =head1 SEE ALSO
 
@@ -125,11 +126,11 @@ Thanks to John Lifsey for writing L<WWW::Wunderground::API>
 
 =head1 AUTHOR
 
-David Farrell <sillymoos@cpan.org>
+David Farrell <dfarrell@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by David Farrell.
+This software is copyright (c) 2015 by David Farrell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
